Exception: GreenGarden::Tree::DatasetNotFound
- Inherits:
-
StandardError
- Object
- StandardError
- GreenGarden::Tree::DatasetNotFound
- Defined in:
- lib/green_garden.rb
Instance Method Summary collapse
-
#initialize(msg = 'Dataset could not be loaded, please check file path') ⇒ DatasetNotFound
constructor
A new instance of DatasetNotFound.
Constructor Details
#initialize(msg = 'Dataset could not be loaded, please check file path') ⇒ DatasetNotFound
Returns a new instance of DatasetNotFound.
15 16 17 |
# File 'lib/green_garden.rb', line 15 def initialize(msg = 'Dataset could not be loaded, please check file path') super end |